sentinel-value
==============

|pypi badge| |build badge| |docs badge|

**Warning!**

**The code is at the early development stage, and may be unstable. Use with caution.**

Links
-----

- Read the Docs: https://sentinel-value.readthedocs.io
- GitHub repository: https://github.com/vdmit11/sentinel-value
- Python package: https://pypi.org/project/sentinel-value/


.. |pypi badge| image:: https://img.shields.io/pypi/v/sentinel-value.svg
  :target: https://pypi.org/project/sentinel-value/
  :alt: Python package version

.. |build badge| image:: https://github.com/vdmit11/sentinel-value/actions/workflows/build.yml/badge.svg
  :target: https://github.com/vdmit11/sentinel-value/actions/workflows/build.yml
  :alt: Tests Status

.. |docs badge| image:: https://readthedocs.org/projects/sentinel-value/badge/?version=latest
  :target: https://sentinel-value.readthedocs.io/en/latest/?badge=latest
  :alt: Documentation Status

